# Contributing

1. Star the project.
2. Open or find an issue [here](https://github.com/mauricioabreu/bojack-py/issues)
3. Fork it (https://github.com/mauricioabreu/bojack-py/fork)
4. Create your feature branch (git checkout -b my-awesome-new-feature)
5. Commit your changes (**follwing our [commit police](#commit-policy)**)
6. Push to the branch (git push origin my-new-feature)
7. Create a new Pull Request

---------

## Commit Policy

We have a very rigid **commit policy**, to contribute please follow these rules:

```
feature: Add hat wobble
 ^--^  ^------------^
 |     |
 |     +-> Summary in present tense
 |
 +-------> Type: chore, doc, feature, fix, refactor, style, or test
```

### Available tags:

 * **chore**: Add oyster build script
 * **doc**: Explain hat wobble
 * **feature**: Add beta sequence
 * **fix**: Remove broken confirmation message
 * **refactor**: Share logic between 4d3d3d3 and flarhgunnstow
 * **style**: Convert tabs to spaces
 * **test**: Ensure Tayne retains clothing

> Based on [this](http://seesparkbox.com/foundry/semantic_commit_messages).
